@@ -1,8 +1,10 @@
 from dataclasses import dataclass
 from typing import Optional
+from uuid import uuid4
 
 import numpy as np
 import rosys
+from rosys.actors.detector import Autoupload
 
 from ..world import Detections, Image, World
 from . import Detector
@@ -13,6 +15,7 @@ class SimulatedObject:
     category_name: str
     position: rosys.world.Point3d
     size: Optional[tuple[float]] = None
+    uuid: str = str(uuid4())
 
 
 class DetectorSimulator(Detector):
@@ -29,7 +32,7 @@ class DetectorSimulator(Detector):
     def is_connected(self):
         return True
 
-    async def detect(self, image: Image) -> Optional[Detections]:
+    async def detect(self, image: Image, autoupload: Autoupload = Autoupload.FILTERED) -> Optional[Detections]:
         is_blocked = image.camera_id in self.blocked_cameras
         await rosys.sleep(0.4)
         image.detections = Detections()
@@ -58,6 +61,7 @@ class DetectorSimulator(Detector):
                     confidence=1.0,
                     x=image_point.x,
                     y=image_point.y,
+                    uuid=object.uuid,
                 )
                 if self.noisy_image_points:
                     detection.x += np.random.randn()
@@ -80,6 +84,7 @@ class DetectorSimulator(Detector):
                     y=image_points[:, 1].min(),
                     width=image_points[:, 0].max() - image_points[:, 0].min(),
                     height=image_points[:, 1].max() - image_points[:, 1].min(),
+                    uuid=object.uuid,
                 )
                 if self.noisy_image_points:
                     detection.x += np.random.randn()
