@@ -3,12 +3,8 @@ from nicegui import ui
 import pylab as pl
 import numpy as np
 import time
-from rosys.world.pose import Pose
-from rosys.world.spline import Spline
-from grid import Grid
-from robot_renderer import RobotRenderer
-from obstacle_map import ObstacleMap
-import plot_tools as pt
+from rosys.world import Pose, Spline
+from rosys.actors.pathplanning import Grid, ObstacleMap, RobotRenderer, plot_tools as pt
 
 grid = Grid((30, 40, 36), (0.45, -0.05, 4.0, 3.0))
 obstacles = [
@@ -19,7 +15,7 @@ robot_renderer = RobotRenderer.from_size(0.77, 1.21, 0.445)
 
 t = time.time()
 obstacle_map = ObstacleMap.from_list(grid, obstacles, robot_renderer)
-ui.label("%.3f ms" % ((time.time() - t) * 1000))
+ui.label('%.3f ms' % ((time.time() - t) * 1000))
 
 start = [1.0, 0.5, 0]
 end = [2.3, 0.9, np.deg2rad(90)]
