@@ -3,17 +3,18 @@ from __future__ import annotations
 import asyncio
 import logging
 from asyncio.exceptions import CancelledError
-from typing import Optional, Type
+from typing import Optional, Type, TypeVar
 
 from . import Persistence, event, is_test, run, sleep, task_logger
-from .actors import (Actor, AsyncioMonitor, Automator, Backup, CameraProjector,
-                     Detector, DetectorSimulator, GarbageCollector, Lizard,
-                     NetworkMonitor, Odometer, PathPlanner, Steerer,
-                     UsbCameraCapture, UsbCameraSimulator)
+from .actors import (Actor, AsyncioMonitor, Automator, Backup, CameraProjector, Detector, DetectorSimulator,
+                     GarbageCollector, Lizard, NetworkMonitor, Odometer, PathPlanner, Steerer, UsbCameraCapture,
+                     UsbCameraSimulator)
 from .communication import CommunicationFactory
 from .hardware import Hardware, RobotBrain, SimulatedHardware
 from .world import World
 
+T = TypeVar('T')
+
 
 class Runtime:
     log = logging.getLogger(__name__)
@@ -33,9 +34,9 @@ class Runtime:
         if is_test:
             assert self.hardware.is_simulation, 'real hardware must not be used in tests'
         self.lizard = Lizard(self.hardware)
+        self.automator = Automator()
         self.odometer = Odometer()
         self.steerer = Steerer(self.hardware)
-        self.automator = Automator()
         self.camera_projector = CameraProjector()
         self.asyncio_monitor = AsyncioMonitor()
         self.detector: Optional[Detector] = None  # NOTE can be set by runtime.with_detector()
@@ -68,7 +69,7 @@ class Runtime:
         return self
 
     def with_usb_cameras(self) -> Runtime:
-        '''Adds usb camera capture actor to runtime.'''
+        '''Adds USB camera capture actor to runtime.'''
         if UsbCameraCapture.is_operable() and not is_test:
             self.with_actors(UsbCameraCapture())
         else:
@@ -91,7 +92,7 @@ class Runtime:
         self.with_actors(self.path_planner)
         return self
 
-    async def startup(self):
+    async def startup(self) -> None:
         if self.tasks:
             raise Exception('should be only executed once')
 
@@ -105,29 +106,29 @@ class Runtime:
             if actor.interval is not None:
                 self.log.debug(f'starting actor {actor.name} with interval {actor.interval}s')
                 self.tasks.append(task_logger.create_task(self.repeat(actor), name=actor.name))
-        self.tasks.append(asyncio.create_task(self.watch_emitted_events()))
-
+        self.tasks.append(asyncio.create_task(self.watch_emitted_events(), name='watch_emitted_events'))
+        await self.hardware.startup()
         if not is_test:
             await asyncio.sleep(1)  # NOTE we wait for RoSys to start up before analyzing async debugging
         self.activate_async_debugging()
-        self.log.debug('startup completed')
+        self.log.info('startup completed')
         self.world.start_time = self.world.time
 
-    async def shutdown(self):
+    async def shutdown(self) -> None:
         try:
             await self.hardware.drive(0, 0)
         except:
             pass
         if not is_test:
             self.persistence.backup()
+        run.tear_down()
         [t.cancel() for t in self.tasks]
-        if not is_test:
-            run.process_pool.shutdown()
         for a in self.actors:
             await a.tear_down()
-        # await asyncio.gather(*[task_logger.create_task(a.tear_down(), name=f'{a.name}.tear_down()') for a in self.actors])
+        await self.hardware.tear_down()
 
     async def repeat(self, actor: Actor):
+        await sleep(actor.interval)  # NOTE delaying first execution so not all actors rush in at the same time
         while True:
             start = self.world.time
             try:
@@ -150,7 +151,7 @@ class Runtime:
             except (CancelledError, GeneratorExit):
                 return
 
-    def get_actor(self, _type: Type[Actor]) -> Actor:
+    def get_actor(self, _type: Type[T]) -> T:
         return next((a for a in self.actors if type(a) is _type), None)
 
     def store_notification(self, message: str):
