@@ -15,4 +15,4 @@ from .profiler import create_profiler
 from .pyloot_page import PylootPage as pyloot_page
 from .robot_object import RobotObject as robot_object
 from .settings import update_interval
-from .wifi import create_wifi
+from .wifi import wifi_button
