@@ -1,6 +1,7 @@
-from nicegui.ui import Ui
-from nicegui.elements.chart import Chart
 import psutil
+from nicegui.elements.chart import Chart
+from nicegui.ui import Ui
+
 from .settings import update_interval
 
 
@@ -21,7 +22,8 @@ class CpuUsage(Chart):
         })
         self.ui.timer(update_interval, self.update)
 
-    def update(self):
+    def update(self) -> bool:
         for i, v in enumerate(psutil.cpu_percent(percpu=True)):
             self.options.series[i].data.append(v)
         [s.data.pop(0) for s in self.options.series if len(s.data) > 20]
+        return False  # NOTE: avoid JustPy page_update
