@@ -1,9 +1,10 @@
-from nicegui.ui import Ui
-import logging
-import socket
-import os.path
-from pathlib import Path
 import asyncio
+import logging
+import os
+import socket
+
+from nicegui import ui
+from nicegui.elements.button import Button
 
 log = logging.getLogger('rosys.wifi')
 
@@ -35,12 +36,12 @@ def has_internet() -> bool:
         return False
 
 
-def create_wifi(ui: Ui):
+def wifi_button() -> Button:
 
     def add(ssid: str, password: str):
         log.info(f'adding {ssid}, {password}')
         wifi_configs = os.path.expanduser(f'~/.rosys/wifi')
-        Path(wifi_configs).mkdir(parents=True, exist_ok=True)
+        os.makedirs(wifi_configs, exist_ok=True)
         # NOTE a daemon on the host system must watch the .rosys/wifi dir and reload the configuration with nmcli or similar
         with open(f'{wifi_configs}/{ssid}', 'w') as f:
             f.write(password)
@@ -65,3 +66,4 @@ def create_wifi(ui: Ui):
 
     wifi_button = ui.button(on_click=dialog.open).props('icon=network_wifi')
     ui.timer(5, callback=update_wifi_status)
+    return wifi_button
